# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from mett_dataportal_sdk.models.genome_paginated_response_schema import (
    GenomePaginatedResponseSchema,
)
from mett_dataportal_sdk.models.success_response_schema import SuccessResponseSchema

from mett_dataportal_sdk.api_client import ApiClient, RequestSerialized
from mett_dataportal_sdk.api_response import ApiResponse
from mett_dataportal_sdk.rest import RESTResponseType


class SpeciesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def dataportal_api_core_species_endpoints_get_all_species(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Get all species

        Get all available species

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_all_species_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_core_species_endpoints_get_all_species_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Get all species

        Get all available species

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_all_species_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_get_all_species_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all species

        Get all available species

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_all_species_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_core_species_endpoints_get_all_species_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/species/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_get_genomes_by_species(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[Optional[StrictStr]]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenomePaginatedResponseSchema:
        """Get genomes by species

        Retrieves genomes under a given species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[Optional[str]]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_genomes_by_species_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_core_species_endpoints_get_genomes_by_species_with_http_info(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[Optional[StrictStr]]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenomePaginatedResponseSchema]:
        """Get genomes by species

        Retrieves genomes under a given species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[Optional[str]]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_genomes_by_species_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_get_genomes_by_species_without_preload_content(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[Optional[StrictStr]]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get genomes by species

        Retrieves genomes under a given species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[Optional[str]]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_genomes_by_species_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_core_species_endpoints_get_genomes_by_species_serialize(
        self,
        species_acronym,
        query,
        page,
        per_page,
        sort_field,
        sort_order,
        isolates,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {
            "isolates": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if species_acronym is not None:
            _path_params["species_acronym"] = species_acronym
        # process the query parameters
        if query is not None:
            _query_params.append(("query", query))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if sort_field is not None:
            _query_params.append(("sortField", sort_field))

        if sort_order is not None:
            _query_params.append(("sortOrder", sort_order))

        if isolates is not None:
            _query_params.append(("isolates", isolates))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/species/{species_acronym}/genomes",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_search_genomes_by_species_and_string(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[StrictStr]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenomePaginatedResponseSchema:
        """Search genomes by species and query string

        Performs a search for genomes within a specific species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_with_http_info(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[StrictStr]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenomePaginatedResponseSchema]:
        """Search genomes by species and query string

        Performs a search for genomes within a specific species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_without_preload_content(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[StrictStr]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search genomes by species and query string

        Performs a search for genomes within a specific species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_serialize(
        self,
        species_acronym,
        query,
        page,
        per_page,
        sort_field,
        sort_order,
        isolates,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {
            "isolates": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if species_acronym is not None:
            _path_params["species_acronym"] = species_acronym
        # process the query parameters
        if query is not None:
            _query_params.append(("query", query))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if sort_field is not None:
            _query_params.append(("sortField", sort_field))

        if sort_order is not None:
            _query_params.append(("sortOrder", sort_order))

        if isolates is not None:
            _query_params.append(("isolates", isolates))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/species/{species_acronym}/genomes/search",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )
