# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Set
from typing_extensions import Self


class GeneAdvancedSearchQuerySchema(BaseModel):
    """
    Schema for advanced gene search across multiple genomes/species with filters.
    """  # noqa: E501

    isolates: Optional[StrictStr] = Field(
        default="", description="Comma-separated list of isolate names to filter."
    )
    species_acronym: Optional[StrictStr] = None
    locus_tag: Optional[StrictStr] = None
    query: Optional[StrictStr] = Field(
        default="",
        description="Free-text search string for gene names, locus tags, or annotations.",
    )
    filter: Optional[StrictStr] = None
    filter_operators: Optional[StrictStr] = None
    page: Optional[StrictInt] = Field(
        default=1, description="Page number for pagination (1-based)."
    )
    per_page: Optional[StrictInt] = Field(
        default=20, description="Number of genes to return per page."
    )
    sort_field: Optional[StrictStr] = None
    sort_order: Optional[StrictStr] = None
    seq_id: Optional[StrictStr] = None
    start_position: Optional[StrictInt] = None
    end_position: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = [
        "isolates",
        "species_acronym",
        "locus_tag",
        "query",
        "filter",
        "filter_operators",
        "page",
        "per_page",
        "sort_field",
        "sort_order",
        "seq_id",
        "start_position",
        "end_position",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GeneAdvancedSearchQuerySchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if species_acronym (nullable) is None
        # and model_fields_set contains the field
        if self.species_acronym is None and "species_acronym" in self.model_fields_set:
            _dict["species_acronym"] = None

        # set to None if locus_tag (nullable) is None
        # and model_fields_set contains the field
        if self.locus_tag is None and "locus_tag" in self.model_fields_set:
            _dict["locus_tag"] = None

        # set to None if filter (nullable) is None
        # and model_fields_set contains the field
        if self.filter is None and "filter" in self.model_fields_set:
            _dict["filter"] = None

        # set to None if filter_operators (nullable) is None
        # and model_fields_set contains the field
        if (
            self.filter_operators is None
            and "filter_operators" in self.model_fields_set
        ):
            _dict["filter_operators"] = None

        # set to None if sort_field (nullable) is None
        # and model_fields_set contains the field
        if self.sort_field is None and "sort_field" in self.model_fields_set:
            _dict["sort_field"] = None

        # set to None if sort_order (nullable) is None
        # and model_fields_set contains the field
        if self.sort_order is None and "sort_order" in self.model_fields_set:
            _dict["sort_order"] = None

        # set to None if seq_id (nullable) is None
        # and model_fields_set contains the field
        if self.seq_id is None and "seq_id" in self.model_fields_set:
            _dict["seq_id"] = None

        # set to None if start_position (nullable) is None
        # and model_fields_set contains the field
        if self.start_position is None and "start_position" in self.model_fields_set:
            _dict["start_position"] = None

        # set to None if end_position (nullable) is None
        # and model_fields_set contains the field
        if self.end_position is None and "end_position" in self.model_fields_set:
            _dict["end_position"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GeneAdvancedSearchQuerySchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "isolates": obj.get("isolates")
                if obj.get("isolates") is not None
                else "",
                "species_acronym": obj.get("species_acronym"),
                "locus_tag": obj.get("locus_tag"),
                "query": obj.get("query") if obj.get("query") is not None else "",
                "filter": obj.get("filter"),
                "filter_operators": obj.get("filter_operators"),
                "page": obj.get("page") if obj.get("page") is not None else 1,
                "per_page": obj.get("per_page")
                if obj.get("per_page") is not None
                else 20,
                "sort_field": obj.get("sort_field"),
                "sort_order": obj.get("sort_order"),
                "seq_id": obj.get("seq_id"),
                "start_position": obj.get("start_position"),
                "end_position": obj.get("end_position"),
            }
        )
        return _obj
