# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Set
from typing_extensions import Self


class AMRSchema(BaseModel):
    """
    AMRSchema
    """  # noqa: E501

    gene_symbol: Optional[StrictStr] = None
    sequence_name: Optional[StrictStr] = None
    scope: Optional[StrictStr] = None
    element_type: Optional[StrictStr] = None
    element_subtype: Optional[StrictStr] = None
    drug_class: Optional[StrictStr] = None
    drug_subclass: Optional[StrictStr] = None
    uf_keyword: Optional[List[StrictStr]] = None
    uf_ecnumber: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "gene_symbol",
        "sequence_name",
        "scope",
        "element_type",
        "element_subtype",
        "drug_class",
        "drug_subclass",
        "uf_keyword",
        "uf_ecnumber",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AMRSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if gene_symbol (nullable) is None
        # and model_fields_set contains the field
        if self.gene_symbol is None and "gene_symbol" in self.model_fields_set:
            _dict["gene_symbol"] = None

        # set to None if sequence_name (nullable) is None
        # and model_fields_set contains the field
        if self.sequence_name is None and "sequence_name" in self.model_fields_set:
            _dict["sequence_name"] = None

        # set to None if scope (nullable) is None
        # and model_fields_set contains the field
        if self.scope is None and "scope" in self.model_fields_set:
            _dict["scope"] = None

        # set to None if element_type (nullable) is None
        # and model_fields_set contains the field
        if self.element_type is None and "element_type" in self.model_fields_set:
            _dict["element_type"] = None

        # set to None if element_subtype (nullable) is None
        # and model_fields_set contains the field
        if self.element_subtype is None and "element_subtype" in self.model_fields_set:
            _dict["element_subtype"] = None

        # set to None if drug_class (nullable) is None
        # and model_fields_set contains the field
        if self.drug_class is None and "drug_class" in self.model_fields_set:
            _dict["drug_class"] = None

        # set to None if drug_subclass (nullable) is None
        # and model_fields_set contains the field
        if self.drug_subclass is None and "drug_subclass" in self.model_fields_set:
            _dict["drug_subclass"] = None

        # set to None if uf_keyword (nullable) is None
        # and model_fields_set contains the field
        if self.uf_keyword is None and "uf_keyword" in self.model_fields_set:
            _dict["uf_keyword"] = None

        # set to None if uf_ecnumber (nullable) is None
        # and model_fields_set contains the field
        if self.uf_ecnumber is None and "uf_ecnumber" in self.model_fields_set:
            _dict["uf_ecnumber"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AMRSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "gene_symbol": obj.get("gene_symbol"),
                "sequence_name": obj.get("sequence_name"),
                "scope": obj.get("scope"),
                "element_type": obj.get("element_type"),
                "element_subtype": obj.get("element_subtype"),
                "drug_class": obj.get("drug_class"),
                "drug_subclass": obj.get("drug_subclass"),
                "uf_keyword": obj.get("uf_keyword"),
                "uf_ecnumber": obj.get("uf_ecnumber"),
            }
        )
        return _obj
