# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import (
    BaseModel,
    ConfigDict,
    StrictBool,
    StrictFloat,
    StrictInt,
    StrictStr,
)
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Set
from typing_extensions import Self


class TTPCompoundInteractionsQuerySchema(BaseModel):
    """
    Schema for getting all interactions for a specific compound.
    """  # noqa: E501

    compound: Optional[StrictStr] = None
    hit_calling: Optional[StrictBool] = None
    species_acronym: Optional[StrictStr] = None
    isolate_name: Optional[StrictStr] = None
    min_ttp_score: Optional[Union[StrictFloat, StrictInt]] = None
    sort_field: Optional[StrictStr] = None
    sort_order: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "compound",
        "hit_calling",
        "species_acronym",
        "isolate_name",
        "min_ttp_score",
        "sort_field",
        "sort_order",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TTPCompoundInteractionsQuerySchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if compound (nullable) is None
        # and model_fields_set contains the field
        if self.compound is None and "compound" in self.model_fields_set:
            _dict["compound"] = None

        # set to None if hit_calling (nullable) is None
        # and model_fields_set contains the field
        if self.hit_calling is None and "hit_calling" in self.model_fields_set:
            _dict["hit_calling"] = None

        # set to None if species_acronym (nullable) is None
        # and model_fields_set contains the field
        if self.species_acronym is None and "species_acronym" in self.model_fields_set:
            _dict["species_acronym"] = None

        # set to None if isolate_name (nullable) is None
        # and model_fields_set contains the field
        if self.isolate_name is None and "isolate_name" in self.model_fields_set:
            _dict["isolate_name"] = None

        # set to None if min_ttp_score (nullable) is None
        # and model_fields_set contains the field
        if self.min_ttp_score is None and "min_ttp_score" in self.model_fields_set:
            _dict["min_ttp_score"] = None

        # set to None if sort_field (nullable) is None
        # and model_fields_set contains the field
        if self.sort_field is None and "sort_field" in self.model_fields_set:
            _dict["sort_field"] = None

        # set to None if sort_order (nullable) is None
        # and model_fields_set contains the field
        if self.sort_order is None and "sort_order" in self.model_fields_set:
            _dict["sort_order"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TTPCompoundInteractionsQuerySchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "compound": obj.get("compound"),
                "hit_calling": obj.get("hit_calling"),
                "species_acronym": obj.get("species_acronym"),
                "isolate_name": obj.get("isolate_name"),
                "min_ttp_score": obj.get("min_ttp_score"),
                "sort_field": obj.get("sort_field"),
                "sort_order": obj.get("sort_order"),
            }
        )
        return _obj
