"""Core API CLI commands."""

from .genes import genes_app
from .genomes import genomes_app
from .species import species_app
from .system import system_app

__all__ = ["genes_app", "genomes_app", "species_app", "system_app"]
