# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mett_dataportal_sdk.models.drug_metabolism_data_schema import (
    DrugMetabolismDataSchema,
)
from mett_dataportal_sdk.models.drug_mic_data_schema import DrugMICDataSchema
from typing import Set
from typing_extensions import Self


class StrainDrugDataResponseSchema(BaseModel):
    """
    Response schema for combined strain drug data (MIC + metabolism).
    """  # noqa: E501

    isolate_name: StrictStr = Field(description="Strain isolate name")
    species_acronym: Optional[StrictStr] = None
    species_scientific_name: Optional[StrictStr] = None
    drug_mic_data: Optional[List[DrugMICDataSchema]] = Field(
        default=None, description="List of drug MIC measurements"
    )
    drug_metabolism_data: Optional[List[DrugMetabolismDataSchema]] = Field(
        default=None, description="List of drug metabolism measurements"
    )
    __properties: ClassVar[List[str]] = [
        "isolate_name",
        "species_acronym",
        "species_scientific_name",
        "drug_mic_data",
        "drug_metabolism_data",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StrainDrugDataResponseSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in drug_mic_data (list)
        _items = []
        if self.drug_mic_data:
            for _item_drug_mic_data in self.drug_mic_data:
                if _item_drug_mic_data:
                    _items.append(_item_drug_mic_data.to_dict())
            _dict["drug_mic_data"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in drug_metabolism_data (list)
        _items = []
        if self.drug_metabolism_data:
            for _item_drug_metabolism_data in self.drug_metabolism_data:
                if _item_drug_metabolism_data:
                    _items.append(_item_drug_metabolism_data.to_dict())
            _dict["drug_metabolism_data"] = _items
        # set to None if species_acronym (nullable) is None
        # and model_fields_set contains the field
        if self.species_acronym is None and "species_acronym" in self.model_fields_set:
            _dict["species_acronym"] = None

        # set to None if species_scientific_name (nullable) is None
        # and model_fields_set contains the field
        if (
            self.species_scientific_name is None
            and "species_scientific_name" in self.model_fields_set
        ):
            _dict["species_scientific_name"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StrainDrugDataResponseSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "isolate_name": obj.get("isolate_name"),
                "species_acronym": obj.get("species_acronym"),
                "species_scientific_name": obj.get("species_scientific_name"),
                "drug_mic_data": [
                    DrugMICDataSchema.from_dict(_item) for _item in obj["drug_mic_data"]
                ]
                if obj.get("drug_mic_data") is not None
                else None,
                "drug_metabolism_data": [
                    DrugMetabolismDataSchema.from_dict(_item)
                    for _item in obj["drug_metabolism_data"]
                ]
                if obj.get("drug_metabolism_data") is not None
                else None,
            }
        )
        return _obj
