# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Set
from typing_extensions import Self


class EssentialitySearchQuerySchema(BaseModel):
    """
    Schema for essentiality search endpoint query parameters.
    """  # noqa: E501

    locus_tags: Optional[StrictStr] = None
    uniprot_ids: Optional[StrictStr] = None
    essentiality_call: Optional[StrictStr] = None
    experimental_condition: Optional[StrictStr] = None
    min_tas_in_locus: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    min_tas_hit: Optional[
        Union[
            Annotated[float, Field(le=1, strict=True, ge=0)],
            Annotated[int, Field(le=1, strict=True, ge=0)],
        ]
    ] = None
    element: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "locus_tags",
        "uniprot_ids",
        "essentiality_call",
        "experimental_condition",
        "min_tas_in_locus",
        "min_tas_hit",
        "element",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EssentialitySearchQuerySchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if locus_tags (nullable) is None
        # and model_fields_set contains the field
        if self.locus_tags is None and "locus_tags" in self.model_fields_set:
            _dict["locus_tags"] = None

        # set to None if uniprot_ids (nullable) is None
        # and model_fields_set contains the field
        if self.uniprot_ids is None and "uniprot_ids" in self.model_fields_set:
            _dict["uniprot_ids"] = None

        # set to None if essentiality_call (nullable) is None
        # and model_fields_set contains the field
        if (
            self.essentiality_call is None
            and "essentiality_call" in self.model_fields_set
        ):
            _dict["essentiality_call"] = None

        # set to None if experimental_condition (nullable) is None
        # and model_fields_set contains the field
        if (
            self.experimental_condition is None
            and "experimental_condition" in self.model_fields_set
        ):
            _dict["experimental_condition"] = None

        # set to None if min_tas_in_locus (nullable) is None
        # and model_fields_set contains the field
        if (
            self.min_tas_in_locus is None
            and "min_tas_in_locus" in self.model_fields_set
        ):
            _dict["min_tas_in_locus"] = None

        # set to None if min_tas_hit (nullable) is None
        # and model_fields_set contains the field
        if self.min_tas_hit is None and "min_tas_hit" in self.model_fields_set:
            _dict["min_tas_hit"] = None

        # set to None if element (nullable) is None
        # and model_fields_set contains the field
        if self.element is None and "element" in self.model_fields_set:
            _dict["element"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EssentialitySearchQuerySchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "locus_tags": obj.get("locus_tags"),
                "uniprot_ids": obj.get("uniprot_ids"),
                "essentiality_call": obj.get("essentiality_call"),
                "experimental_condition": obj.get("experimental_condition"),
                "min_tas_in_locus": obj.get("min_tas_in_locus"),
                "min_tas_hit": obj.get("min_tas_hit"),
                "element": obj.get("element"),
            }
        )
        return _obj
