"""Shared constants for the METT client ecosystem."""

# Production URL
DEFAULT_BASE_URL = "http://www.gut-microbes.org"

# For local development, set METT_BASE_URL environment variable:
# export METT_BASE_URL="http://localhost:8000"

__all__ = ["DEFAULT_BASE_URL"]
