# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from mett_dataportal_sdk.models.success_response_schema import SuccessResponseSchema

from mett_dataportal_sdk.api_client import ApiClient, RequestSerialized
from mett_dataportal_sdk.api_response import ApiResponse
from mett_dataportal_sdk.rest import RESTResponseType


class EssentialityApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def dataportal_api_experimental_essentiality_endpoints_search_essentiality(
        self,
        locus_tags: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of locus tags to search for"),
        ] = None,
        uniprot_ids: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of UniProt IDs to search for"),
        ] = None,
        essentiality_call: Annotated[
            Optional[StrictStr],
            Field(
                description="Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)"
            ),
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr],
            Field(description="Filter by experimental condition/media"),
        ] = None,
        min_tas_in_locus: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=0)]],
            Field(description="Minimum number of transposon insertion sites"),
        ] = None,
        min_tas_hit: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Minimum fraction of transposon sites hit (0-1)"),
        ] = None,
        element: Annotated[
            Optional[StrictStr],
            Field(description="Filter by element type (gene, intergenic, etc.)"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Search essentiality data with filters

        Search for essentiality data across genes with optional filters. Supports identifier-based search and discovery mode (filter-only queries).

        :param locus_tags: Comma-separated list of locus tags to search for
        :type locus_tags: str
        :param uniprot_ids: Comma-separated list of UniProt IDs to search for
        :type uniprot_ids: str
        :param essentiality_call: Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)
        :type essentiality_call: str
        :param experimental_condition: Filter by experimental condition/media
        :type experimental_condition: str
        :param min_tas_in_locus: Minimum number of transposon insertion sites
        :type min_tas_in_locus: int
        :param min_tas_hit: Minimum fraction of transposon sites hit (0-1)
        :type min_tas_hit: float
        :param element: Filter by element type (gene, intergenic, etc.)
        :type element: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_essentiality_endpoints_search_essentiality_serialize(
            locus_tags=locus_tags,
            uniprot_ids=uniprot_ids,
            essentiality_call=essentiality_call,
            experimental_condition=experimental_condition,
            min_tas_in_locus=min_tas_in_locus,
            min_tas_hit=min_tas_hit,
            element=element,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_experimental_essentiality_endpoints_search_essentiality_with_http_info(
        self,
        locus_tags: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of locus tags to search for"),
        ] = None,
        uniprot_ids: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of UniProt IDs to search for"),
        ] = None,
        essentiality_call: Annotated[
            Optional[StrictStr],
            Field(
                description="Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)"
            ),
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr],
            Field(description="Filter by experimental condition/media"),
        ] = None,
        min_tas_in_locus: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=0)]],
            Field(description="Minimum number of transposon insertion sites"),
        ] = None,
        min_tas_hit: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Minimum fraction of transposon sites hit (0-1)"),
        ] = None,
        element: Annotated[
            Optional[StrictStr],
            Field(description="Filter by element type (gene, intergenic, etc.)"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Search essentiality data with filters

        Search for essentiality data across genes with optional filters. Supports identifier-based search and discovery mode (filter-only queries).

        :param locus_tags: Comma-separated list of locus tags to search for
        :type locus_tags: str
        :param uniprot_ids: Comma-separated list of UniProt IDs to search for
        :type uniprot_ids: str
        :param essentiality_call: Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)
        :type essentiality_call: str
        :param experimental_condition: Filter by experimental condition/media
        :type experimental_condition: str
        :param min_tas_in_locus: Minimum number of transposon insertion sites
        :type min_tas_in_locus: int
        :param min_tas_hit: Minimum fraction of transposon sites hit (0-1)
        :type min_tas_hit: float
        :param element: Filter by element type (gene, intergenic, etc.)
        :type element: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_essentiality_endpoints_search_essentiality_serialize(
            locus_tags=locus_tags,
            uniprot_ids=uniprot_ids,
            essentiality_call=essentiality_call,
            experimental_condition=experimental_condition,
            min_tas_in_locus=min_tas_in_locus,
            min_tas_hit=min_tas_hit,
            element=element,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_experimental_essentiality_endpoints_search_essentiality_without_preload_content(
        self,
        locus_tags: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of locus tags to search for"),
        ] = None,
        uniprot_ids: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of UniProt IDs to search for"),
        ] = None,
        essentiality_call: Annotated[
            Optional[StrictStr],
            Field(
                description="Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)"
            ),
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr],
            Field(description="Filter by experimental condition/media"),
        ] = None,
        min_tas_in_locus: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=0)]],
            Field(description="Minimum number of transposon insertion sites"),
        ] = None,
        min_tas_hit: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Minimum fraction of transposon sites hit (0-1)"),
        ] = None,
        element: Annotated[
            Optional[StrictStr],
            Field(description="Filter by element type (gene, intergenic, etc.)"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search essentiality data with filters

        Search for essentiality data across genes with optional filters. Supports identifier-based search and discovery mode (filter-only queries).

        :param locus_tags: Comma-separated list of locus tags to search for
        :type locus_tags: str
        :param uniprot_ids: Comma-separated list of UniProt IDs to search for
        :type uniprot_ids: str
        :param essentiality_call: Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)
        :type essentiality_call: str
        :param experimental_condition: Filter by experimental condition/media
        :type experimental_condition: str
        :param min_tas_in_locus: Minimum number of transposon insertion sites
        :type min_tas_in_locus: int
        :param min_tas_hit: Minimum fraction of transposon sites hit (0-1)
        :type min_tas_hit: float
        :param element: Filter by element type (gene, intergenic, etc.)
        :type element: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_essentiality_endpoints_search_essentiality_serialize(
            locus_tags=locus_tags,
            uniprot_ids=uniprot_ids,
            essentiality_call=essentiality_call,
            experimental_condition=experimental_condition,
            min_tas_in_locus=min_tas_in_locus,
            min_tas_hit=min_tas_hit,
            element=element,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_experimental_essentiality_endpoints_search_essentiality_serialize(
        self,
        locus_tags,
        uniprot_ids,
        essentiality_call,
        experimental_condition,
        min_tas_in_locus,
        min_tas_hit,
        element,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if locus_tags is not None:
            _query_params.append(("locus_tags", locus_tags))

        if uniprot_ids is not None:
            _query_params.append(("uniprot_ids", uniprot_ids))

        if essentiality_call is not None:
            _query_params.append(("essentiality_call", essentiality_call))

        if experimental_condition is not None:
            _query_params.append(("experimental_condition", experimental_condition))

        if min_tas_in_locus is not None:
            _query_params.append(("min_tas_in_locus", min_tas_in_locus))

        if min_tas_hit is not None:
            _query_params.append(("min_tas_hit", min_tas_hit))

        if element is not None:
            _query_params.append(("element", element))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/essentiality/search",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )
