# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mett_dataportal_sdk.models.pagination_metadata_schema import (
    PaginationMetadataSchema,
)
from mett_dataportal_sdk.models.ppi_interaction_schema import PPIInteractionSchema
from mett_dataportal_sdk.models.response_status import ResponseStatus
from typing import Set
from typing_extensions import Self


class PPISearchResponseSchema(BaseModel):
    """
    Response schema for PPI search results.
    """  # noqa: E501

    status: Optional[ResponseStatus] = Field(
        default=None, description="Response status"
    )
    message: Optional[StrictStr] = None
    timestamp: StrictStr = Field(description="ISO 8601 timestamp of the response")
    data: List[PPIInteractionSchema]
    pagination: PaginationMetadataSchema = Field(description="Pagination metadata")
    __properties: ClassVar[List[str]] = [
        "status",
        "message",
        "timestamp",
        "data",
        "pagination",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PPISearchResponseSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data (list)
        _items = []
        if self.data:
            for _item_data in self.data:
                if _item_data:
                    _items.append(_item_data.to_dict())
            _dict["data"] = _items
        # override the default output from pydantic by calling `to_dict()` of pagination
        if self.pagination:
            _dict["pagination"] = self.pagination.to_dict()
        # set to None if message (nullable) is None
        # and model_fields_set contains the field
        if self.message is None and "message" in self.model_fields_set:
            _dict["message"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PPISearchResponseSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "status": obj.get("status"),
                "message": obj.get("message"),
                "timestamp": obj.get("timestamp"),
                "data": [PPIInteractionSchema.from_dict(_item) for _item in obj["data"]]
                if obj.get("data") is not None
                else None,
                "pagination": PaginationMetadataSchema.from_dict(obj["pagination"])
                if obj.get("pagination") is not None
                else None,
            }
        )
        return _obj
